@@ -430,7 +430,13 @@ def get_swagger_dict(api_url: str) -> dict:
     swagger_file = requests.get(swagger_url)
 
     if swagger_file.status_code == 200:
-        return json.loads(swagger_file.text)
+        swagger = json.loads(swagger_file.text)
+
+        app_name = swagger.get("info", {}).get("title", {})
+        if app_name is None or app_name != "LUSID API":
+            raise ValueError(f"Invalid LUSID OpenAPI file: {swagger_url}")
+
+        return swagger
     else:
         raise ValueError(
             f"""Received a {swagger_file.status_code} response from the provided url, please double check
@@ -850,11 +856,15 @@ def handle_nested_default_and_column_mapping(
                 mapping_updated[key] = f"LUSID.{key}"
                 data_frame[mapping_updated[key]] = value[1:]
 
+        elif isinstance(value, int):
+            mapping_updated[key] = f"LUSID.{key}"
+            data_frame[mapping_updated[key]] = value
+
         else:
             raise ValueError(
                 f"""You have passed in a value with type {type(value)} for the mapping for {key}, this is
                                  not a supported type. Please provide a string with the column name to use, a constant
-                                 value prefixed by {constant_prefix} or a dictionary
+                                 value prefixed by {constant_prefix},an integer value or a dictionary
                                  with the keys "column" and "default" where column is the column name and default
                                  being the default value to use."""
             )
@@ -1005,6 +1015,9 @@ def parse_args(args: dict):
         help=r"full path to mappings.json (see mappings_template.json)",
     )
     ap.add_argument("-s", "--scope", help=r"LUSID scope to act in")
+    ap.add_argument(
+        "-ps", "--property_scope", help=r"LUSID scope to load properties into"
+    )
     ap.add_argument(
         "-dl",
         "--delimiter",
